==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/savesubtitledialog.h <==
#ifndef SAVESUBTITLEDIALOG_H
#define SAVESUBTITLEDIALOG_H

/***************************************************************************
*   Copyright (C) 2007-2008 by Sergio Pistone                             *
*   sergio_pistone@yahoo.com.ar                                           *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <kencodingfiledialog.h>

class KComboBox;

namespace SubtitleComposer
{
	class SaveSubtitleDialog : public KEncodingFileDialog
	{
		public:

			typedef enum {
				UNIX = 0,
				Windows,
				Macintosh,
#ifdef Q_OS_UNIX
				CurrentOS = UNIX,
#else
	#ifdef Q_OS_WIN
				CurrentOS = Windows,
	#else
				CurrentOS = Macintosh,
	#endif
#endif
			} NewLine;

			SaveSubtitleDialog( bool primary, const QString& startDir=QString::null, const QString& encoding=QString::null, int newLine=CurrentOS, const QString& format=QString::null, QWidget* parent=0 );

			QString selectedFormat();

			NewLine selectedNewLine();
	
			static QString buildOutputFormatsFilter();

		private:

			KComboBox* m_newLineComboBox;
	};
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/main/dialogs/savesubtitledialog.h <==
#ifndef SAVESUBTITLEDIALOG_H
#define SAVESUBTITLEDIALOG_H

/***************************************************************************
*   Copyright (C) 2007-2008 by Sergio Pistone                             *
*   sergio_pistone@yahoo.com.ar                                           *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <kencodingfiledialog.h>

class KComboBox;

namespace SubtitleComposer
{
	class SaveSubtitleDialog : public KEncodingFileDialog
	{
		public:

			typedef enum {
				UNIX = 0,
				Windows,
				Macintosh,
#ifdef Q_OS_UNIX
				CurrentOS = UNIX,
#else
	#ifdef Q_OS_WIN
				CurrentOS = Windows,
	#else
				CurrentOS = Macintosh,
	#endif
#endif
			} NewLine;

			SaveSubtitleDialog( bool primary, const QString& startDir=QString::null, const QString& encoding=QString::null, int newLine=CurrentOS, const QString& format=QString::null, QWidget* parent=0 );

			QString selectedFormat();

			NewLine selectedNewLine();
	
			static QString outputFormatsFilter();

		public slots:

			int exec();

		private:

			KComboBox* m_newLineComboBox;
	};
}

#endif
